==> robotframework_remote_monitor_library-1.5.7-py3-none-any.whl: RemoteMonitorLibrary/runner/html_writer.py <==
import os

HTML = """
<!DOCTYPE html>
<html>
    <head>
        <style>
            * {{
              box-sizing: border-box;
            }}
            
            .column {{
              float: left;
              width: 33.33%;
              padding: 5px;
            }}
            
            /* Clearfix (clear floats) */
            .row::after {{
              content: "";
              clear: both;
              display: table;
            }}
            
            @media screen and (max-width: 500px) {{
              .column {{
                width: 100%;
              }}
            }}
    </style>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <title>{title}</title>
</head>
    <body>
        <h1>{title}</h1><br>
        <div class="row">
          {body}
        </div>
    </body>
</html>
"""

HTML_IMAGE_REF = """
            <div class="column">
                <h3>{picture_title}</h3>
                <img src="{relative_path}" style="width:100%">
            </div>
"""


def create_html(report_abs_path, report_rel_path, file_name: str, *body_data) -> str:
    html_file_name = "{}.html".format(file_name) if not file_name.endswith('.html') else file_name
    html_full_path = os.path.normpath(os.path.join(report_abs_path, report_rel_path, html_file_name))
    html_link_path = '/'.join([report_rel_path, html_file_name])

    body = ''.join([HTML_IMAGE_REF.format(relative_path=file_path, picture_title=picture_name)
                    for picture_name, file_path in body_data])

    with open(html_full_path, 'w') as sw:
        sw.write(HTML.format(title=file_name, body=body))
    return html_link_path

==> robotframework_remote_monitor_library-2.1.4.3-py3-none-any.whl: RemoteMonitorLibrary/runner/html_writer.py <==
import os

HTML = """
<!DOCTYPE html>
<html>
    <head>
        <style>
            * {{
              box-sizing: border-box;
            }}
            
            .column {{
              float: left;
              width: 33.33%;
              padding: 5px;
            }}
            
            /* Clearfix (clear floats) */
            .row::after {{
              content: "";
              clear: both;
              display: table;
            }}
            
            @media screen and (max-width: 500px) {{
              .column {{
                width: 100%;
              }}
            }}
    </style>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <title>{title}</title>
</head>
    <body>
        <h1>{title}</h1><br>
        <div class="row">
          {body}
        </div>
    </body>
</html>
"""

HTML_IMAGE_REF = """
            <div class="column">
                <img src="{relative_path}" style="width:100%">
            </div>
"""


def create_html(report_abs_path, report_rel_path, file_name: str, *body_data) -> str:
    html_file_name = "{}.html".format(file_name) if not file_name.endswith('.html') else file_name
    html_full_path = os.path.normpath(os.path.join(report_abs_path, report_rel_path, html_file_name))
    html_link_path = '/'.join([report_rel_path, html_file_name])

    body = ''.join([HTML_IMAGE_REF.format(relative_path=file_path)
                    for picture_name, file_path in body_data])

    with open(html_full_path, 'w') as sw:
        sw.write(HTML.format(title=file_name, body=body))
    return html_link_path
